@@ -1620,6 +1620,61 @@ class DescribeFlowResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeInstanceNodeInfoRequest(AbstractModel):
+    """DescribeInstanceNodeInfo request structure.
+
+    """
+
+    def __init__(self):
+        """
+        :param InstanceId: Instance ID, such as tdsql-6ltok4u9
+        :type InstanceId: str
+        :param Limit: The maximum number of results returned at a time. By default, there is no upper limit to this value, that is, all results can be returned.
+        :type Limit: int
+        :param Offset: Offset of the returned results. Default value: `0`.
+        :type Offset: int
+        """
+        self.InstanceId = None
+        self.Limit = None
+        self.Offset = None
+
+
+    def _deserialize(self, params):
+        self.InstanceId = params.get("InstanceId")
+        self.Limit = params.get("Limit")
+        self.Offset = params.get("Offset")
+
+
+class DescribeInstanceNodeInfoResponse(AbstractModel):
+    """DescribeInstanceNodeInfo response structure.
+
+    """
+
+    def __init__(self):
+        """
+        :param TotalCount: Total number of nodes
+        :type TotalCount: int
+        :param NodesInfo: Node information
+        :type NodesInfo: list of NodeInfo
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :type RequestId: str
+        """
+        self.TotalCount = None
+        self.NodesInfo = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.TotalCount = params.get("TotalCount")
+        if params.get("NodesInfo") is not None:
+            self.NodesInfo = []
+            for item in params.get("NodesInfo"):
+                obj = NodeInfo()
+                obj._deserialize(item)
+                self.NodesInfo.append(obj)
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeLogFileRetentionPeriodRequest(AbstractModel):
     """DescribeLogFileRetentionPeriod request structure.
 
@@ -2234,6 +2289,27 @@ class MonitorData(AbstractModel):
         self.Data = params.get("Data")
 
 
+class NodeInfo(AbstractModel):
+    """Instance node information
+
+    """
+
+    def __init__(self):
+        """
+        :param NodeId: Node ID
+        :type NodeId: str
+        :param Role: Node role. Valid values: `master`, `slave`
+        :type Role: str
+        """
+        self.NodeId = None
+        self.Role = None
+
+
+    def _deserialize(self, params):
+        self.NodeId = params.get("NodeId")
+        self.Role = params.get("Role")
+
+
 class OpenDBExtranetAccessRequest(AbstractModel):
     """OpenDBExtranetAccess request structure.
 
