@@ -251,7 +251,7 @@ class RedisClient(AbstractClient):
 
 
     def DescribeCommonDBInstances(self, request):
-        """This API is used to query information of the Redis instance list.
+        """(Disused) Queries the list of instances
 
         :param request: Request instance for DescribeCommonDBInstances.
         :type request: :class:`tencentcloud.redis.v20180412.models.DescribeCommonDBInstancesRequest`
@@ -1643,6 +1643,34 @@ class RedisClient(AbstractClient):
                 message = response["Response"]["Error"]["Message"]
                 reqid = response["Response"]["RequestId"]
                 raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def UpgradeVersionToMultiAvailabilityZones(self, request):
+        """This API is used to upgrade an instance to support multi-AZ deployment.
+
+        :param request: Request instance for UpgradeVersionToMultiAvailabilityZones.
+        :type request: :class:`tencentcloud.redis.v20180412.models.UpgradeVersionToMultiAvailabilityZonesRequest`
+        :rtype: :class:`tencentcloud.redis.v20180412.models.UpgradeVersionToMultiAvailabilityZonesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("UpgradeVersionToMultiAvailabilityZones", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.UpgradeVersionToMultiAvailabilityZonesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
